{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../configuration/common

      ./backup-scripts.nix
    ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "palladium";

  networking.useDHCP = false;
  networking.interfaces.enp3s0.ipv6.addresses = [ { address = "2a01:4f8:1c0c:8221::11"; prefixLength = 64; } ];
  networking.defaultGateway6 = { address = "2a01:4f8:1c0c:8221::1"; interface = "enp3s0"; };
  networking.nameservers = [ "fd00:152:152::1" ];

  # Keeping the harddrives quiet
  services.udev.extraRules = ''
    KERNEL=="sd?[0-9]", ENV{ID_MODEL}=="ST1000DM003-1SB102", ACTION=="add", RUN+="${pkgs.hdparm}/sbin/hdparm -S 24 /dev/%k"
  '';

  services.borgbackup.repos.clerie-backup = {
    path = "/mnt/palladium/clerie-backup";
    authorizedKeysAppendOnly = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFyk716RnbenPMkhLolyIkU8ywUSg8x7hjsXFFQoJx4I root@clerie-backup"
    ];
  };

  clerie.monitoring = {
    enable = true;
    id = "206";
    pubkey = "fHOYNZ5I3E2JPrd9dUrNBmu75weX4KbDih5q+GCk8Xk=";
  };

  system.stateVersion = "21.03";

}
